@@ -6,6 +6,7 @@ from .chained_function_checker import ChainedDotFunctionsSyntaxChecker
 from .confluence_page_checker import ConfluencePageChecker
 from .author_checker import AuthorChecker
 from .case_import_checker import CaseImportChecker
+from .module_display_checker import ModuleDisplayChecker
 
 def register(linter):
     linter.register_checker(FunctionCallChecker(linter))
@@ -16,3 +17,4 @@ def register(linter):
     linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
     linter.register_checker(AuthorChecker(linter))
     linter.register_checker(CaseImportChecker(linter))
+    linter.register_checker(ModuleDisplayChecker(linter))
