@@ -41,7 +41,7 @@ class SelectCastChecker(BaseChecker):
         self._function_stack.append([])
 
     def visit_expr(self, node):
-        if select_contains_alias_call(node):
+        if select_contains_cast_call(node):
             self.add_message("select-contains-cast", node=node)
 
     def leave_functiondef(self, node):
